const vertex = require('vertex360')({ site_id: process.env.TURBO_APP_ID })
const Job = require('../models/Job')
const Controller = vertex.Controller

class JobController extends Controller {
  constructor () {
    super(Job, process.env)
  }

  get (params) {
    return new Promise((resolve, reject) => {
      Job.find(params, Controller.parseFilters(params))
        .then(jobs => {
          resolve(Job.convertToJson(jobs))
        })
        .catch(err => {
          reject(err)
        })
    })
  }

  getById (id) {
    return new Promise((resolve, reject) => {
      Job.findById(id)
        .then(job => {
          if (job == null) {
            throw new Error(Job.resourceName + ' ' + id + ' not found.')
          }

          resolve(job.summary())
        })
        .catch(err => {
          reject(err)
        })
    })
  }

  post (body) {
    return new Promise((resolve, reject) => {
      body.dateString = vertex.utils.formattedDate()

      Job.create(body)
        .then(job => {
          resolve(job.summary())
        })
        .catch(err => {
          reject(err)
        })
    })
  }

  put (id, params) {
    return new Promise((resolve, reject) => {
      Job.findByIdAndUpdate(id, params, { new: true })
        .then(job => {
          resolve(job.summary())
        })
        .catch(err => {
          reject(err)
        })
    })
  }

  delete (id) {
    return new Promise((resolve, reject) => {
      Job.findByIdAndRemove(id)
        .then(() => {
          resolve()
        })
        .catch(err => {
          reject(err)
        })
    })
  }
}

module.exports = JobController
