const vertex = require('vertex360')({ site_id: process.env.TURBO_APP_ID })
const Controller = vertex.Controller
const School = require('../models/School')

class SchoolController extends Controller {
  constructor () {
    super(School, process.env)
  }

  get (params) {
    return new Promise((resolve, reject) => {
      School.find(params, Controller.parseFilters(params))
        .then(schools => {
          resolve(School.convertToJson(schools))
        })
        .catch(err => {
          reject(err)
        })
    })
  }

  getById (id) {
    return new Promise((resolve, reject) => {
      School.findById(id)
        .then(school => {
          if (school == null) {
            throw new Error(School.resourceName + ' ' + id + ' not found.')
          }

          resolve(school.summary())
        })
        .catch(err => {
          reject(err)
        })
    })
  }

  post (body) {
    return new Promise((resolve, reject) => {
      body.dateString = vertex.utils.formattedDate()

      School.create(body)
        .then(school => {
          resolve(school.summary())
        })
        .catch(err => {
          reject(err)
        })
    })
  }

  put (id, params) {
    return new Promise((resolve, reject) => {
      School.findByIdAndUpdate(id, params, { new: true })
        .then(school => {
          resolve(school.summary())
        })
        .catch(err => {
          reject(err)
        })
    })
  }

  delete (id) {
    return new Promise((resolve, reject) => {
      School.findByIdAndRemove(id)
        .then(() => {
          resolve()
        })
        .catch(err => {
          reject(err)
        })
    })
  }
}

module.exports = SchoolController
