const vertex = require('vertex360')({ site_id: process.env.TURBO_APP_ID })
const Controller = vertex.Controller
const Profile = require('../models/Profile')

class ProfileController extends Controller {
  constructor () {
    super(Profile, process.env)
  }

  get (params) {
    return new Promise((resolve, reject) => {
      Profile.find(params, Controller.parseFilters(params))
        .then(profiles => {
          resolve(Profile.convertToJson(profiles))
        })
        .catch(err => {
          reject(err)
        })
    })
  }

  getById (id) {
    return new Promise((resolve, reject) => {
      Profile.findById(id)
        .then(profile => {
          if (profile == null) {
            throw new Error(Profile.resourceName + ' ' + id + ' not found.')
          }

          resolve(profile.summary())
        })
        .catch(err => {
          reject(err)
        })
    })
  }

  post (body) {
    return new Promise((resolve, reject) => {
      Profile.create(body)
        .then(profile => {
          resolve(profile.summary())
        })
        .catch(err => {
          reject(err)
        })
    })
  }

  put (id, params) {
    return new Promise((resolve, reject) => {
      Profile.findByIdAndUpdate(id, params, { new: true })
        .then(profile => {
          resolve(profile.summary())
        })
        .catch(err => {
          reject(err)
        })
    })
  }

  delete (id) {
    return new Promise((resolve, reject) => {
      Profile.findByIdAndRemove(id)
        .then(() => {
          resolve()
        })
        .catch(err => {
          reject(err)
        })
    })
  }
}

module.exports = ProfileController
